@@ -1,4 +1,3 @@
-import os
 import sys
 import time
 import traceback
@@ -6,16 +5,25 @@ import traceback
 from docker import DockerClient
 from docker.errors import APIError
 from zuper_commons.types import ZException
+from .credentials import DockerCredentials
 
 from . import logger
 
-__all__ = ["run_build", "BuildFailed"]
+__all__ = ["run_build", "BuildFailed", "log_in_for_build"]
+
+from .dockerfile_utils import get_resolved_from
+from .docker_logging_in import do_login_for_image
 
 
 class BuildFailed(ZException):
     pass
 
 
+def log_in_for_build(dockerfile_contents: str, credentials: DockerCredentials):
+    for x in get_resolved_from(dockerfile_contents):
+        do_login_for_image(credentials, x)
+
+
 def run_build(client: DockerClient, rm=True, **kwargs):
     """
 
@@ -38,6 +46,7 @@ def run_build_(client: DockerClient, **kwargs):
     """ Raises BuildFailed """
     # logger.info("now running build", cwd=os.getcwd(), kwargs=kwargs)
     try:
+        logger.debug("Running build... [silence is docker creating the context]")
         for line in client.api.build(**kwargs, decode=True):
             # logger.debug(line=line)
             line = _build_line(line)
