@@ -1,3 +1,4 @@
+import getpass
 import os
 import sys
 import time
@@ -10,9 +11,9 @@ from docker import DockerClient
 from zuper_commons.fs import write_ustring_to_utf8_file
 from zuper_commons.types import ZException, ZValueError
 
-from .caching import docker_caching
 from . import logger
 from .buildresult import get_complete_tag, parse_complete_tag
+from .caching import docker_caching
 from .credentials import DockerCredentials
 from .docker_logging_in import do_login_for_registry
 from .types import DockerCompleteImageName, DockerImageDigest
@@ -206,9 +207,12 @@ def push_image(
                 sys.stderr.flush()
 
     logger.debug(f"Push successful.", image_name=image_name, final_digest=final_digest)
-
-    fn = "/tmp/duckietown/dt-build-utils/" + tag.repository + ".push_history.yaml"
-    write_ustring_to_utf8_file(yaml.dump(all_lines), fn)
+    user = getpass.getuser()
+    try:
+        fn = f"/tmp/{user}/duckietown/dt-build-utils/" + tag.repository + ".push_history.yaml"
+        write_ustring_to_utf8_file(yaml.dump(all_lines), fn)
+    except:
+        pass
 
     if br.tag is not None:
         docker_caching.mark_tag_pushed(
